# لنبدأ!

مرحبًا بك في Rapunzel، بيئة التطوير الحديثة لـ Python و R. هذه بعض اختصارات لوحة المفاتيح المفيدة.

## العمل مع مجلدات المشروع والملفات

- [`Ctrl+Shift+O`: فتح مجلد المشروع](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: فتح ملف من مجلدات المشروع](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: إنشاء مستند فارغ](opensesame://event.ide_new_file)

## القيام بالأمور بسرعة

- [`Ctrl+Shift+P`: تنشيط لوحة الأوامر](opensesame://event.command_palette_activate)
- `Ctrl+R`: الانتقال إلى دالة أو فئة

## تشغيل الرمز

- `F5`: تشغيل المشروع أو الملف
- `F9`: تشغيل التحديد أو الخلية أو السطر الحالي